@@ -62,6 +62,7 @@ typedef struct
 
   gchar              *id;
   gchar              *settings_path;
+  GVariant           *initial_settings;
   gchar              *gettext_domain;
   gboolean            locked_down;
   GtkOrientation      orientation;
@@ -86,6 +87,7 @@ enum
 
   PROP_ID,
   PROP_SETTINGS_PATH,
+  PROP_INITIAL_SETTINGS,
   PROP_GETTEXT_DOMAIN,
   PROP_LOCKED_DOWN,
   PROP_ORIENTATION,
@@ -291,6 +293,7 @@ static void
 gp_applet_constructed (GObject *object)
 {
   GpApplet *applet;
+  GpAppletClass *applet_class;
   GpAppletPrivate *priv;
   GActionGroup *group;
   GtkStyleContext *context;
@@ -298,8 +301,13 @@ gp_applet_constructed (GObject *object)
   G_OBJECT_CLASS (gp_applet_parent_class)->constructed (object);
 
   applet = GP_APPLET (object);
+  applet_class = GP_APPLET_GET_CLASS (applet);
   priv = gp_applet_get_instance_private (applet);
 
+  if (applet_class->initial_setup != NULL && priv->initial_settings != NULL)
+    applet_class->initial_setup (applet, priv->initial_settings);
+  g_clear_pointer (&priv->initial_settings, g_variant_unref);
+
   gtk_builder_set_translation_domain (priv->builder, priv->gettext_domain);
 
   group = G_ACTION_GROUP (priv->action_group);
@@ -327,6 +335,7 @@ gp_applet_dispose (GObject *object)
       priv->size_hints_idle = 0;
     }
 
+  g_clear_pointer (&priv->initial_settings, g_variant_unref);
   g_clear_object (&priv->general_settings);
 
   G_OBJECT_CLASS (gp_applet_parent_class)->dispose (object);
@@ -371,6 +380,10 @@ gp_applet_get_property (GObject    *object,
         g_value_set_string (value, priv->settings_path);
         break;
 
+      case PROP_INITIAL_SETTINGS:
+        g_value_set_variant (value, priv->initial_settings);
+        break;
+
       case PROP_GETTEXT_DOMAIN:
         g_value_set_string (value, priv->gettext_domain);
         break;
@@ -429,6 +442,11 @@ gp_applet_set_property (GObject      *object,
         priv->settings_path = g_value_dup_string (value);
         break;
 
+      case PROP_INITIAL_SETTINGS:
+        g_assert (priv->initial_settings == NULL);
+        priv->initial_settings = g_value_dup_variant (value);
+        break;
+
       case PROP_GETTEXT_DOMAIN:
         g_assert (priv->gettext_domain == NULL);
         priv->gettext_domain = g_value_dup_string (value);
@@ -572,6 +590,17 @@ install_properties (GObjectClass *object_class)
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
                          G_PARAM_STATIC_STRINGS);
 
+  /**
+   * GpApplet:initial-settings:
+   *
+   * The GVariant with initial settings.
+   */
+  properties[PROP_INITIAL_SETTINGS] =
+    g_param_spec_variant ("initial-settings", "Initial Settings", "Initial Settings",
+                          G_VARIANT_TYPE ("a{sv}"), NULL,
+                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE |
+                          G_PARAM_STATIC_STRINGS);
+
   /**
    * GpApplet:gettext-domain:
    *
